@@ -648,7 +648,7 @@ def test_allow_redirects_samehost():
     assert_reset()
 
 
-def test_handles_chinese_url():
+def test_handles_unicode_querystring():
     url = u'http://example.com/test?type=2&ie=utf8&query=汉字'
 
     @responses.activate
@@ -663,6 +663,21 @@ def test_handles_chinese_url():
     assert_reset()
 
 
+def test_handles_unicode_url():
+    url = u'http://www.संजाल.भारत/hi/वेबसाइट-डिजाइन'
+
+    @responses.activate
+    def run():
+        responses.add(responses.GET, url, body='test')
+
+        resp = requests.get(url)
+
+        assert_response(resp, 'test')
+
+    run()
+    assert_reset()
+
+
 def test_headers():
     @responses.activate
     def run():
@@ -749,3 +764,38 @@ def test_passthru(httpserver):
 
     run()
     assert_reset()
+
+
+def test_method_named_param():
+    @responses.activate
+    def run():
+        responses.add(
+            method=responses.GET, url='http://example.com', body='OK')
+        resp = requests.get('http://example.com')
+        assert_response(resp, 'OK')
+
+    run()
+    assert_reset()
+
+
+def test_passthru_unicode():
+    @responses.activate
+    def run():
+        with responses.RequestsMock() as m:
+            url = u'http://موقع.وزارة-الاتصالات.مصر/'
+            clean_url = 'http://xn--4gbrim.xn----ymcbaaajlc6dj7bxne2c.xn--wgbh1c/'
+            m.add_passthru(url)
+            assert m.passthru_prefixes[0] == clean_url
+
+    run()
+    assert_reset()
+
+
+def test_custom_target(monkeypatch):
+    requests_mock = responses.RequestsMock(target='something.else')
+    std_mock_mock = responses.std_mock.MagicMock()
+    patch_mock = std_mock_mock.patch
+    monkeypatch.setattr(responses, 'std_mock', std_mock_mock)
+    requests_mock.start()
+    assert len(patch_mock.call_args_list) == 1
+    assert patch_mock.call_args[1]['target'] == 'something.else'
